BOLOS
=====

``BOLOS`` is a BOLtzmann equation solver Open Source library.  

This package provides a pure Python library for the solution of the 
Boltzmann equation for electrons in a non-thermal plasma.  It builds upon
previous work, mostly by G. J. M. Hagelaar and L. C. Pitchford [HP2005]_, 
who developed `Bolsig+`_.  ``BOLOS`` is a multiplatform, open source 
implementation of a similar algorithm compatible with the `Bolsig+`_ 
cross-section input format.


The code was developed by `Alejandro Luque <http://www.iaa.es/~aluque>`_ at the 
`Instituto de Astrofísica de Andalucía <http://www.iaa.es>`_ (IAA), `CSIC <http://www.csic.es>`_ and is licensed under the `LGPLv2 License`_. Packages can be 
downloaded from the project `homepage`_ on PyPI. The 
`source code`_ can be obtained from
GitHub, which also hosts the `bug tracker`_. The `documentation`_  can be
read on ReadTheDocs.


.. _LGPLv2 License: http://www.gnu.org/licenses/lgpl-2.0.html
.. _BOLSIG+: http://www.bolsig.laplace.univ-tlse.fr/
.. _homepage: http://pypi.python.org/pypi/bolos/
.. _documentation: http://bolos.readthedocs.org/
.. _source code: https://github.com/aluque/bolos
.. _bug tracker: https://github.com/aluque/bolos/issues
.. [HP2005] *Solving the Boltzmann equation to obtain electron transport coefficients and rate coefficients for fluid models*, G. J. M. Hagelaar and L. C. Pitchford, Plasma Sources Sci. Technol. **14** (2005) 722–733.



